==> nextcloud-jitsi-v0.16.2.tar.gz: jitsi/l10n/eu.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "konferentziak",
    "Jitsi Integration" : "Jitsi integrazioa",
    "Conferences" : "Konferentziak",
    "Jitsi Integration (unofficial)" : "Jitsi integrazioa (ez ofiziala)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Aplikazio honek Jitsi konferentziak integratzen ditu Nextclouden.\n\nEzaugarriak:\n- 🎥 Lineazko konferentzia errazak Netxclouden Jitsi erabiliz\n- 🔗 Konferentzia gela partekatze-estekak\n- 🔎 Konferentzia gelak erakusten ditu bilaketa globalean\n- ✅ Sistema probatzen da konferenzia batera sartu baino lehen\n\nMesedez irakurri [dokumentazioa](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Kargatzen ...",
    "Server URL (required)" : "Zerbitzariaren URLa (beharrezkoa)",
    "Help link (optional)" : "Laguntza-esteka (aukerazkoa)",
    "Display \"Join using the Jitsi app\"" : "Erakutsi \"Sartu Jitsi aplikazioa erabiliz\"",
    "JWT Secret (optional)" : "JWT sekretua (aukerazkoa)",
    "JWT App ID" : "JWT aplikazioaren ID",
    "JWT Audience (optional)" : "JWT audientzia (aukerazkoa)",
    "JWT Issuer (optional)" : "JWT emailea (aukerazkoa)",
    "save" : "gorde",
    "saved" : "gordeta",
    "Saving …" : "Gordetzen ...",
    "Please provide a Jitsi instance URL" : "Mesedez eman Jitsi instantzia URL bat",
    "The server URL must start with https://" : "Zerbitzariaren URLa https:// hasi behar da",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Oso gomendagarria da berariazko Jitsi instantzia konfiguratzea",
    "Please provide the App ID" : "Hornitu aplikazioaren IDa mesedez",
    "Failed to save settings" : "Huts egin du ezarpenak gordetzean",
    "Failed to load settings" : "Huts egin du ezarpenak kargatzean",
    "Conference rooms" : "Konferentzia gelak",
    "Conference" : "Biltzarra",
    "Conference left" : "Konferentzia utzi da",
    "Problems detected" : "Arazoak aurkitu dira",
    "Your browser is non-optimal:" : "Zure nabigatzailea ez da optimoa:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Audio eta bideo kalitatea txarra izan daiteke.<b>Firefox/Chrome/Chromium</b> bertsio berri bat erabiltzea gomendatzen da.",
    "Browser not supported" : "Ez da nabigatzailea onartzen",
    "Show system check" : "Erakutsi sistemaren egiaztapena",
    "Your name:" : "Zure izena:",
    "Click here to join" : "Egin klik hemen sartzeko",
    "Start muted" : "Hasi mutututa",
    "Start with camera off" : "Hasi kamerarekin itzalita",
    "Link copied" : "Esteka kopiatu da",
    "Cannot copy, please copy the link manually" : "Ezin izan da kopiatu. Kopiatu esteka eskuz",
    "Copy to clipboard" : "Kopiatu arbelera",
    "Browser" : "Nabigatzailea",
    "non-optimal" : "ez da optimoa",
    "not supported" : "ez da onartzen",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Audio eta bideo kalitatea txarra izan daiteke.<br> <b>Firefox/Chrome/Chromium</b> bertsio berri bat erabiltzea gomendatzen da.",
    "Help" : "Laguntza",
    "Camera" : "Kamera",
    "Name of the new room" : "Gelaren izen berria",
    "No conference rooms yet" : "Ez dago konferentzia gelarik oraindik",
    "Create the first room:" : "Sortu lehen gela:",
    "Microphone" : "Mikrofonoa",
    "Join" : "Batu",
    "Delete room" : "Gela borratu",
    "Room not found" : "Ez da gela aurkitu",
    "Please check the link/URL and ask your host" : "Mesedez egiaztatu esteka/URLa eta galdetu zure ostalariari",
    "Audio output" : "Audio irteera",
    "Play test sound" : "Erreproduzitu proba-soinua",
    "System check" : "Sistema egiaztatu",
    "Got issues?" : "Arazorik duzu?",
    "Known problems / what you can try" : "Arazo ezagunak / zer egin dezakezu",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Onartu mikrofono/kamera sarbide baimenak pantaila-hasieran",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Egiaztatu mikrofono/kamera sarbide baimenak helbide-barra ondoan dagoen ikonoan klik eginez. Gero, freskatu orria.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• IDroidCam baduzu: Konektatu mugikorraren kamerara eta freskatu orria",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Saiatu sartzen Jitsi aplikazioa erabiliz (jarraitu orriaren bukaeran dauden argibideak)",
    "No camera/microphone access" : "Ez dago kamera/mikrofono sarbiderik",
    "Review your browser camera and microphone access settings" : "Berrikusi zure nabigatzailearen kamera eta mikrofono sarbide baimenak",
    "Click here for {browser} instructions" : "Egin klik hemen {browser}-(r)en argibideentzako",
    "Does not work?" : "Ez du funtzionatzen?",
    "Click here for troubleshooting help" : "Egin klik hemen arazoak konpontzeko laguntza jasotzeko",
    "Conferences app not yet configured" : "Konferentzia aplikazioa ez dago konfiguratuta oraindik",
    "Please contact your administrator to set up the conferences app." : "Jarri harremanetan zure administratzailearekin konferentzia aplikazioa konfiguratzeko mesedez.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Zure nabigatzailea (%1$s) zaharkitua dago eta <br> ez dago onartuta",
    "It is recommended to use the latest version of one of the following browsers:" : "Hurrengo nabigatzaileetariko azken bertsioa erabiltzea gomendatzen da:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/eu.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "konferentziak",
    "Jitsi Integration" : "Jitsi integrazioa",
    "Conferences" : "Konferentziak",
    "Jitsi Integration (unofficial)" : "Jitsi integrazioa (ez ofiziala)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Aplikazio honek Jitsi konferentziak integratzen ditu Nextclouden.\n\nEzaugarriak:\n- 🎥 Lineazko konferentzia errazak Netxclouden Jitsi erabiliz\n- 🔗 Konferentzia gela partekatze-estekak\n- 🔎 Konferentzia gelak erakusten ditu bilaketa globalean\n- ✅ Sistema probatzen da konferenzia batera sartu baino lehen\n\nMesedez irakurri [dokumentazioa](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Kargatzen ...",
    "Server URL (required)" : "Zerbitzariaren URLa (beharrezkoa)",
    "Help link (optional)" : "Laguntza-esteka (hautazkoa)",
    "Display \"Join using the Jitsi app\"" : "Erakutsi \"Sartu Jitsi aplikazioa erabiliz\"",
    "JWT Secret (optional)" : "JWT sekretua (hautazkoa)",
    "JWT App ID" : "JWT aplikazioaren ID",
    "JWT Audience (optional)" : "JWT audientzia (aukerazkoa)",
    "JWT Issuer (optional)" : "JWT emailea (aukerazkoa)",
    "save" : "gorde",
    "saved" : "gordeta",
    "Saving …" : "Gordetzen ...",
    "Please provide a Jitsi instance URL" : "Mesedez eman Jitsi instantzia URL bat",
    "The server URL must start with https://" : "Zerbitzariaren URLa https:// hasi behar da",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Oso gomendagarria da berariazko Jitsi instantzia konfiguratzea",
    "Please provide the App ID" : "Hornitu aplikazioaren IDa mesedez",
    "Failed to save settings" : "Ezarpenak gordetzeak huts egin du",
    "Failed to load settings" : "Ezarpenak kargatzeak huts egin du",
    "Conference rooms" : "Konferentzia gelak",
    "Conference" : "Biltzarra",
    "Conference left" : "Konferentzia utzi da",
    "Problems detected" : "Arazoak aurkitu dira",
    "Your browser is non-optimal:" : "Zure nabigatzailea ez da optimoa:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Audio eta bideo kalitatea txarra izan daiteke.<b>Firefox/Chrome/Chromium</b> bertsio berri bat erabiltzea gomendatzen da.",
    "Browser not supported" : "Ez da nabigatzailea onartzen",
    "Show system check" : "Erakutsi sistemaren egiaztapena",
    "Your name:" : "Zure izena:",
    "Click here to join" : "Egin klik hemen sartzeko",
    "Start muted" : "Hasi mutututa",
    "Start with camera off" : "Hasi kamerarekin itzalita",
    "Join with desktop app" : "Sartu mahaigaineko aplikazioarekin",
    "Join with mobile app" : "Sartu mugikorreko aplikazioarekin",
    "App button not working?" : "Aplikazioaren botoiak ez du funtzionatzen?",
    "Download the desktop app here ↗" : "Deskargatu mahaigaineko aplikazioa hemen ↗",
    "The mobile app is available via the app store of your choice." : "Mugikorrko aplikazioa ez dago eskuragarri hautatutako aplikazio-dendan.",
    "After successful installation try the button again." : "Instalatu ostean, probatu botoia berriro.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Oraindik ez du funtzionatzen? Kopiatu azpiko esteka eta itsatsi ezazu Jitsi aplikazioaren hasiera-pantailan.",
    "Link copied" : "Esteka kopiatu da",
    "Cannot copy, please copy the link manually" : "Ezin izan da kopiatu. Kopiatu esteka eskuz",
    "Copy to clipboard" : "Kopiatu arbelera",
    "Browser" : "Nabigatzailea",
    "non-optimal" : "ez da optimoa",
    "not supported" : "ez da onartzen",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Audio eta bideo kalitatea txarra izan daiteke.<br> <b>Firefox/Chrome/Chromium</b> bertsio berri bat erabiltzea gomendatzen da.",
    "Help" : "Laguntza",
    "Camera" : "Kamera",
    "Name of the new room" : "Gelaren izen berria",
    "No conference rooms yet" : "Ez dago konferentzia gelarik oraindik",
    "Create the first room:" : "Sortu lehen gela:",
    "Microphone" : "Mikrofonoa",
    "Join" : "Batu",
    "Delete room" : "Gela ezabatu",
    "Room not found" : "Ez da gela aurkitu",
    "Please check the link/URL and ask your host" : "Mesedez egiaztatu esteka/URLa eta galdetu zure ostalariari",
    "Audio output" : "Audio irteera",
    "Play test sound" : "Erreproduzitu proba-soinua",
    "System check" : "Sistema egiaztatu",
    "Got issues?" : "Arazorik duzu?",
    "Known problems / what you can try" : "Arazo ezagunak / zer egin dezakezu",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Onartu mikrofono/kamera sarbide baimenak pantaila-hasieran",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Egiaztatu mikrofono/kamera sarbide baimenak helbide-barra ondoan dagoen ikonoan klik eginez. Gero, freskatu orria.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• IDroidCam baduzu: Konektatu mugikorraren kamerara eta freskatu orria",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Saiatu sartzen Jitsi aplikazioa erabiliz (jarraitu orriaren bukaeran dauden argibideak)",
    "No camera/microphone access" : "Ez dago kamera/mikrofono sarbiderik",
    "Review your browser camera and microphone access settings" : "Berrikusi zure nabigatzailearen kamera eta mikrofono sarbide baimenak",
    "Click here for {browser} instructions" : "Egin klik hemen {browser}-(r)en argibideentzako",
    "Does not work?" : "Ez du funtzionatzen?",
    "Click here for troubleshooting help" : "Egin klik hemen arazoak konpontzeko laguntza jasotzeko",
    "Conferences app not yet configured" : "Konferentzia aplikazioa ez dago konfiguratuta oraindik",
    "Please contact your administrator to set up the conferences app." : "Jarri harremanetan zure administratzailearekin konferentzia aplikazioa konfiguratzeko mesedez.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Zure nabigatzailea (%1$s) zaharkitua dago eta <br> ez dago onartuta",
    "It is recommended to use the latest version of one of the following browsers:" : "Hurrengo nabigatzaileetariko azken bertsioa erabiltzea gomendatzen da:"
},
"nplurals=2; plural=(n != 1);");
